Code walkthrough
=================
This guide will take you through the Python API. It will introduce you to the coding concepts and explain how the different components are strung together to form the different pipelines.

Coming soon.

.. Generator pipelines with bash-like syntax.
	 Core pipelines
	 Introduce SQL structure
	 Adding colums is pretty cheap (how?)
